@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -18,59 +20,13 @@
 //! @{
 
 
-template<typename T1>
-arma_warn_unused
-arma_inline
-const Op<T1, op_min>
-min
-  (
-  const T1& X,
-  const uword dim = 0,
-  const typename enable_if< is_arma_type<T1>::value       == true  >::result* junk1 = 0,
-  const typename enable_if< resolves_to_vector<T1>::value == false >::result* junk2 = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
-  
-  return Op<T1, op_min>(X, dim, 0);
-  }
-
-
-template<typename T1>
-arma_warn_unused
-arma_inline
-const Op<T1, op_min>
-min
-  (
-  const T1& X,
-  const uword dim,
-  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk);
-  
-  return Op<T1, op_min>(X, dim, 0);
-  }
-
-
-
 template<typename T1>
 arma_warn_unused
 inline
-typename T1::elem_type
-min
-  (
-  const T1& X,
-  const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
-  )
+typename enable_if2< is_arma_type<T1>::value && resolves_to_vector<T1>::yes, typename T1::elem_type >::result
+min(const T1& X)
   {
   arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
   
   return op_min::min(X);
   }
@@ -79,14 +35,13 @@ min
 
 template<typename T1>
 arma_warn_unused
-inline
-typename T1::elem_type
-min(const Op<T1, op_min>& in)
+arma_inline
+typename enable_if2< is_arma_type<T1>::value && resolves_to_vector<T1>::no, const Op<T1, op_min> >::result
+min(const T1& X)
   {
   arma_extra_debug_sigprint();
-  arma_extra_debug_print("min(): two consecutive min() calls detected");
   
-  return op_min::min(in.m);
+  return Op<T1, op_min>(X, 0, 0);
   }
 
 
@@ -94,12 +49,12 @@ min(const Op<T1, op_min>& in)
 template<typename T1>
 arma_warn_unused
 arma_inline
-const Op< Op<T1, op_min>, op_min>
-min(const Op<T1, op_min>& in, const uword dim)
+typename enable_if2< is_arma_type<T1>::value, const Op<T1, op_min> >::result
+min(const T1& X, const uword dim)
   {
   arma_extra_debug_sigprint();
   
-  return Op< Op<T1, op_min>, op_min>(in, dim, 0);
+  return Op<T1, op_min>(X, dim, 0);
   }
 
 
@@ -107,7 +62,7 @@ min(const Op<T1, op_min>& in, const uword dim)
 template<typename T>
 arma_warn_unused
 arma_inline
-const typename arma_scalar_only<T>::result &
+typename arma_scalar_only<T>::result
 min(const T& x)
   {
   return x;
@@ -178,7 +133,7 @@ inline
 typename
 enable_if2
   <
-  (is_arma_sparse_type<T1>::value == true) && (resolves_to_sparse_vector<T1>::value == true),
+  is_arma_sparse_type<T1>::value && resolves_to_sparse_vector<T1>::yes,
   typename T1::elem_type
   >::result
 min(const T1& x)
@@ -196,10 +151,28 @@ inline
 typename
 enable_if2
   <
-  (is_arma_sparse_type<T1>::value == true) && (resolves_to_sparse_vector<T1>::value == false),
+  is_arma_sparse_type<T1>::value && resolves_to_sparse_vector<T1>::no,
   const SpOp<T1, spop_min>
   >::result
-min(const T1& X, const uword dim = 0)
+min(const T1& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  return SpOp<T1, spop_min>(X, 0, 0);
+  }
+
+
+
+template<typename T1>
+arma_warn_unused
+inline
+typename
+enable_if2
+  <
+  is_arma_sparse_type<T1>::value,
+  const SpOp<T1, spop_min>
+  >::result
+min(const T1& X, const uword dim)
   {
   arma_extra_debug_sigprint();
   
@@ -208,29 +181,75 @@ min(const T1& X, const uword dim = 0)
 
 
 
-template<typename T1>
+// elementwise sparse min
+template<typename T1, typename T2>
 arma_warn_unused
 inline
-typename T1::elem_type
-min(const SpOp<T1, spop_min>& X)
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_sparse_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  const SpGlue<T1, T2, spglue_min>
+  >::result
+min(const T1& x, const T2& y)
   {
   arma_extra_debug_sigprint();
-  arma_extra_debug_print("min(): two consecutive min() calls detected");
-  
-  return spop_min::vector_min(X.m);
+
+  return SpGlue<T1, T2, spglue_min>(x, y);
   }
 
 
 
-template<typename T1>
-arma_warn_unused
+//! elementwise min of dense and sparse objects with the same element type
+template<typename T1, typename T2>
 inline
-const SpOp< SpOp<T1, spop_min>, spop_min>
-min(const SpOp<T1, spop_min>& in, const uword dim)
+typename
+enable_if2
+  <
+  (is_arma_type<T1>::value && is_arma_sparse_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  Mat<typename T1::elem_type>
+  >::result
+min
+  (
+  const T1& x,
+  const T2& y
+  )
   {
   arma_extra_debug_sigprint();
   
-  return SpOp< SpOp<T1, spop_min>, spop_min>(in, dim, 0);
+  Mat<typename T1::elem_type> out;
+  
+  spglue_min::dense_sparse_min(out, x, y);
+  
+  return out;
+  }
+
+
+
+//! elementwise min of sparse and dense objects with the same element type
+template<typename T1, typename T2>
+inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  Mat<typename T1::elem_type>
+  >::result
+min
+  (
+  const T1& x,
+  const T2& y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<typename T1::elem_type> out;
+  
+  // Just call the other order (these operations are commutative)
+  // TODO: if there is a matrix size mismatch, the debug assert will print the matrix sizes in wrong order
+  spglue_min::dense_sparse_min(out, y, x);
+  
+  return out;
   }
 
 
