@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -61,11 +63,28 @@ glue_conv::apply(Mat<eT>& out, const Mat<eT>& A, const Mat<eT>& B, const bool A_
   
   eT* out_mem = out.memptr();
   
-  for(uword i=0; i < out_n_elem; ++i)
+  if( (arma_config::openmp) && (x_n_elem >= 128) && (h_n_elem >= 64) && (mp_thread_limit::in_parallel() == false) )
     {
-    // out_mem[i] = dot( hh, xx.subvec(i, (i + h_n_elem_m1)) );
-    
-    out_mem[i] = op_dot::direct_dot( h_n_elem, hh_mem, &(xx_mem[i]) );
+    #if defined(ARMA_USE_OPENMP)
+      {
+      const int n_threads = mp_thread_limit::get();
+      
+      #pragma omp parallel for schedule(static) num_threads(n_threads)
+      for(uword i=0; i < out_n_elem; ++i)
+        {
+        out_mem[i] = op_dot::direct_dot( h_n_elem, hh_mem, &(xx_mem[i]) );
+        }
+      }
+    #endif
+    }
+  else
+    {
+    for(uword i=0; i < out_n_elem; ++i)
+      {
+      // out_mem[i] = dot( hh, xx.subvec(i, (i + h_n_elem_m1)) );
+      
+      out_mem[i] = op_dot::direct_dot( h_n_elem, hh_mem, &(xx_mem[i]) );
+      }
     }
   }
 
@@ -262,24 +281,57 @@ glue_conv2::apply(Mat<eT>& out, const Mat<eT>& A, const Mat<eT>& B)
   
   out.set_size( out_n_rows, out_n_cols );
   
-  for(uword col=0; col < out_n_cols; ++col)
+  if( (arma_config::openmp) && (out_n_cols >= 2) && (mp_thread_limit::in_parallel() == false) )
     {
-    eT* out_colptr = out.colptr(col);
-    
-    for(uword row=0; row < out_n_rows; ++row)
+    #if defined(ARMA_USE_OPENMP)
       {
-      // out.at(row, col) = accu( H % X(row, col, size(H)) );
+      const int n_threads = mp_thread_limit::get();
       
-      eT acc = eT(0);
-      
-      for(uword H_col = 0; H_col < H_n_cols; ++H_col)
+      #pragma omp parallel for schedule(static) num_threads(n_threads)
+      for(uword col=0; col < out_n_cols; ++col)
         {
-        const eT* X_colptr = X.colptr(col + H_col);
+        eT* out_colptr = out.colptr(col);
         
-        acc += op_dot::direct_dot( H_n_rows, H.colptr(H_col), &(X_colptr[row]) );
+        for(uword row=0; row < out_n_rows; ++row)
+          {
+          // out.at(row, col) = accu( H % X(row, col, size(H)) );
+          
+          eT acc = eT(0);
+          
+          for(uword H_col = 0; H_col < H_n_cols; ++H_col)
+            {
+            const eT* X_colptr = X.colptr(col + H_col);
+            
+            acc += op_dot::direct_dot( H_n_rows, H.colptr(H_col), &(X_colptr[row]) );
+            }
+          
+          out_colptr[row] = acc;
+          }
         }
+      }
+    #endif
+    }
+  else
+    {
+    for(uword col=0; col < out_n_cols; ++col)
+      {
+      eT* out_colptr = out.colptr(col);
       
-      out_colptr[row] = acc;
+      for(uword row=0; row < out_n_rows; ++row)
+        {
+        // out.at(row, col) = accu( H % X(row, col, size(H)) );
+        
+        eT acc = eT(0);
+        
+        for(uword H_col = 0; H_col < H_n_cols; ++H_col)
+          {
+          const eT* X_colptr = X.colptr(col + H_col);
+          
+          acc += op_dot::direct_dot( H_n_rows, H.colptr(H_col), &(X_colptr[row]) );
+          }
+        
+        out_colptr[row] = acc;
+        }
       }
     }
   }
