@@ -1,9 +1,19 @@
-// Copyright (C) 2010-2015 Conrad Sanderson
-// Copyright (C) 2010-2015 NICTA (www.nicta.com.au)
+// SPDX-License-Identifier: Apache-2.0
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
+// 
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
+// 
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup op_cumsum
@@ -23,6 +33,8 @@ op_cumsum::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim)
   
   out.set_size(n_rows,n_cols);
   
+  if(out.n_elem == 0)  { return; }
+  
   if(dim == 0)
     {
     if(n_cols == 1)
@@ -132,13 +144,28 @@ op_cumsum::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum>& in)
 template<typename T1>
 inline
 void
-op_cumsum_simple::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_simple>& in)
+op_cumsum_vec::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_cumsum_vec>& in)
   {
   arma_extra_debug_sigprint();
   
-  const Op<T1,op_cumsum> tmp(in.m, in.aux_uword_a, 0);
+  typedef typename T1::elem_type eT;
   
-  op_cumsum::apply(out, tmp);
+  const quasi_unwrap<T1> U(in.m);
+  
+  const uword dim = (T1::is_xvec) ? uword(U.M.is_rowvec() ? 1 : 0) : uword((T1::is_row) ? 1 : 0);
+  
+  if(U.is_alias(out))
+    {
+    Mat<eT> tmp;
+    
+    op_cumsum::apply_noalias(tmp, U.M, dim);
+    
+    out.steal_mem(tmp);
+    }
+  else
+    {
+    op_cumsum::apply_noalias(out, U.M, dim);
+    }
   }
 
 
